@@ -29,7 +29,7 @@ from tfimm.utils import (
 from .resnetv2 import ResNetV2, ResNetV2Config, ResNetV2Stem
 
 # model_registry will add each entrypoint fn to this
-__all__ = ["ViT", "ViTConfig"]
+__all__ = ["ViT", "ViTBlock", "ViTConfig"]
 
 
 @dataclass
@@ -119,25 +119,38 @@ class ViTConfig(ModelConfig):
 
 
 class ViTMultiHeadAttention(tf.keras.layers.Layer):
-    def __init__(self, cfg: ViTConfig, **kwargs):
+    def __init__(
+        self,
+        embed_dim: int,
+        nb_heads: int,
+        qkv_bias: bool,
+        drop_rate: float,
+        attn_drop_rate: float,
+        **kwargs,
+    ):
         super().__init__(**kwargs)
-        head_dim = cfg.embed_dim // cfg.nb_heads
+        self.embed_dim = embed_dim
+        self.nb_heads = nb_heads
+        self.qkv_bias = qkv_bias
+        self.drop_rate = drop_rate
+        self.attn_drop_rate = attn_drop_rate
+
+        head_dim = embed_dim // nb_heads
         self.scale = head_dim ** -0.5
-        self.cfg = cfg
 
         self.qkv = tf.keras.layers.Dense(
-            units=3 * cfg.embed_dim, use_bias=cfg.qkv_bias, name="qkv"
+            units=3 * embed_dim, use_bias=qkv_bias, name="qkv"
         )
-        self.attn_drop = tf.keras.layers.Dropout(rate=cfg.attn_drop_rate)
-        self.proj = tf.keras.layers.Dense(units=cfg.embed_dim, name="proj")
-        self.proj_drop = tf.keras.layers.Dropout(rate=cfg.drop_rate)
+        self.attn_drop = tf.keras.layers.Dropout(rate=attn_drop_rate)
+        self.proj = tf.keras.layers.Dense(units=embed_dim, name="proj")
+        self.proj_drop = tf.keras.layers.Dropout(rate=drop_rate)
 
     def call(self, x, training=False):
         # B (batch size), N (sequence length), D (embedding dimension),
         # H (number of heads)
         batch_size, seq_length = tf.unstack(tf.shape(x)[:2])
         qkv = self.qkv(x)  # (B, N, 3*D)
-        qkv = tf.reshape(qkv, (batch_size, seq_length, 3, self.cfg.nb_heads, -1))
+        qkv = tf.reshape(qkv, (batch_size, seq_length, 3, self.nb_heads, -1))
         qkv = tf.transpose(qkv, (2, 0, 3, 1, 4))  # (3, B, H, N, D/H)
         q, k, v = qkv[0], qkv[1], qkv[2]
 
@@ -154,20 +167,48 @@ class ViTMultiHeadAttention(tf.keras.layers.Layer):
         return x
 
 
-class Block(tf.keras.layers.Layer):
-    def __init__(self, cfg: ViTConfig, **kwargs):
+class ViTBlock(tf.keras.layers.Layer):
+    def __init__(
+        self,
+        embed_dim: int,
+        nb_heads: int,
+        mlp_ratio: float,
+        qkv_bias: bool,
+        drop_rate: float,
+        attn_drop_rate: float,
+        drop_path_rate: float,
+        norm_layer: str,
+        act_layer: str,
+        **kwargs,
+    ):
         super().__init__(**kwargs)
-        self.norm_layer = norm_layer_factory(cfg.norm_layer)
+        self.embed_dim = embed_dim
+        self.nb_heads = nb_heads
+        self.mlp_ratio = mlp_ratio
+        self.qkv_bias = qkv_bias
+        self.drop_rate = drop_rate
+        self.attn_drop_rate = attn_drop_rate
+        self.drop_path_rate = drop_path_rate
+        self.norm_layer = norm_layer
+        self.act_layer = act_layer
+        norm_layer = norm_layer_factory(norm_layer)
 
-        self.norm1 = self.norm_layer(name="norm1")
-        self.attn = ViTMultiHeadAttention(cfg, name="attn")
-        self.drop_path = DropPath(drop_prob=cfg.drop_path_rate)
-        self.norm2 = self.norm_layer(name="norm2")
+        self.norm1 = norm_layer(name="norm1")
+        self.attn = ViTMultiHeadAttention(
+            embed_dim=embed_dim,
+            nb_heads=nb_heads,
+            qkv_bias=qkv_bias,
+            drop_rate=drop_rate,
+            attn_drop_rate=attn_drop_rate,
+            name="attn",
+        )
+        self.drop_path = DropPath(drop_prob=drop_path_rate)
+        self.norm2 = norm_layer(name="norm2")
         self.mlp = MLP(
-            hidden_dim=int(cfg.embed_dim * cfg.mlp_ratio),
-            embed_dim=cfg.embed_dim,
-            drop_rate=cfg.drop_rate,
-            act_layer=cfg.act_layer,
+            hidden_dim=int(embed_dim * mlp_ratio),
+            embed_dim=embed_dim,
+            drop_rate=drop_rate,
+            act_layer=act_layer,
             name="mlp",
         )
 
@@ -280,7 +321,21 @@ class ViT(tf.keras.Model):
         self.pos_embed = None
         self.pos_drop = tf.keras.layers.Dropout(rate=cfg.drop_rate)
 
-        self.blocks = [Block(cfg, name=f"blocks/{j}") for j in range(cfg.nb_blocks)]
+        self.blocks = [
+            ViTBlock(
+                embed_dim=cfg.embed_dim,
+                nb_heads=cfg.nb_heads,
+                mlp_ratio=cfg.mlp_ratio,
+                qkv_bias=cfg.qkv_bias,
+                drop_rate=cfg.drop_rate,
+                attn_drop_rate=cfg.attn_drop_rate,
+                drop_path_rate=cfg.drop_path_rate,
+                norm_layer=cfg.norm_layer,
+                act_layer=cfg.act_layer,
+                name=f"blocks/{j}",
+            )
+            for j in range(cfg.nb_blocks)
+        ]
         self.norm = self.norm_layer(name="norm")
 
         # Some models have a representation layer on top of cls token
@@ -416,7 +471,7 @@ def vit_tiny_patch16_224():
     """ViT-Tiny (Vit-Ti/16)"""
     cfg = ViTConfig(
         name="vit_tiny_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=192,
         nb_blocks=12,
@@ -430,7 +485,7 @@ def vit_tiny_patch16_384():
     """ViT-Tiny (Vit-Ti/16) @ 384x384."""
     cfg = ViTConfig(
         name="vit_tiny_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=192,
@@ -446,7 +501,7 @@ def vit_small_patch32_224():
     """ViT-Small (ViT-S/32)"""
     cfg = ViTConfig(
         name="vit_small_patch32_224",
-        url="",
+        url="[timm]",
         patch_size=32,
         embed_dim=384,
         nb_blocks=12,
@@ -460,7 +515,7 @@ def vit_small_patch32_384():
     """ViT-Small (ViT-S/32) at 384x384."""
     cfg = ViTConfig(
         name="vit_small_patch32_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=32,
         embed_dim=384,
@@ -476,7 +531,7 @@ def vit_small_patch16_224():
     """ViT-Small (ViT-S/16)"""
     cfg = ViTConfig(
         name="vit_small_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=384,
         nb_blocks=12,
@@ -490,7 +545,7 @@ def vit_small_patch16_384():
     """ViT-Small (ViT-S/16)"""
     cfg = ViTConfig(
         name="vit_small_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=384,
@@ -510,7 +565,7 @@ def vit_base_patch32_224():
     """
     cfg = ViTConfig(
         name="vit_base_patch32_224",
-        url="",
+        url="[timm]",
         patch_size=32,
         embed_dim=768,
         nb_blocks=12,
@@ -528,7 +583,7 @@ def vit_base_patch32_384():
     """
     cfg = ViTConfig(
         name="vit_base_patch32_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=32,
         embed_dim=768,
@@ -548,7 +603,7 @@ def vit_base_patch16_224():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=768,
         nb_blocks=12,
@@ -566,7 +621,7 @@ def vit_base_patch16_384():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=768,
@@ -586,7 +641,7 @@ def vit_base_patch8_224():
     """
     cfg = ViTConfig(
         name="vit_base_patch8_224",
-        url="",
+        url="[timm]",
         patch_size=8,
         embed_dim=768,
         nb_blocks=12,
@@ -603,7 +658,7 @@ def vit_large_patch32_224():
     """
     cfg = ViTConfig(
         name="vit_large_patch32_224",
-        url="",
+        url="[timm]",
         patch_size=32,
         embed_dim=1024,
         nb_blocks=24,
@@ -621,7 +676,7 @@ def vit_large_patch32_384():
     """
     cfg = ViTConfig(
         name="vit_large_patch32_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=32,
         embed_dim=1024,
@@ -641,7 +696,7 @@ def vit_large_patch16_224():
     """
     cfg = ViTConfig(
         name="vit_large_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=1024,
         nb_blocks=24,
@@ -659,7 +714,7 @@ def vit_large_patch16_384():
     """
     cfg = ViTConfig(
         name="vit_large_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=1024,
@@ -678,7 +733,7 @@ def vit_base_patch32_sam_224():
     """
     cfg = ViTConfig(
         name="vit_base_patch32_sam_224",
-        url="",
+        url="[timm]",
         patch_size=32,
         embed_dim=768,
         nb_blocks=12,
@@ -695,7 +750,7 @@ def vit_base_patch16_sam_224():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_sam_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=768,
         nb_blocks=12,
@@ -713,7 +768,7 @@ def vit_tiny_patch16_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_tiny_patch16_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=16,
         embed_dim=192,
@@ -732,7 +787,7 @@ def vit_small_patch32_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_small_patch32_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=32,
         embed_dim=384,
@@ -751,7 +806,7 @@ def vit_small_patch16_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_small_patch16_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=16,
         embed_dim=384,
@@ -771,7 +826,7 @@ def vit_base_patch32_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_base_patch32_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=32,
         embed_dim=768,
@@ -791,7 +846,7 @@ def vit_base_patch16_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=16,
         embed_dim=768,
@@ -810,7 +865,7 @@ def vit_base_patch8_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_base_patch8_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=8,
         embed_dim=768,
@@ -831,7 +886,7 @@ def vit_large_patch32_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_large_patch32_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=32,
         embed_dim=1024,
@@ -852,7 +907,7 @@ def vit_large_patch16_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_large_patch16_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=16,
         embed_dim=1024,
@@ -873,7 +928,7 @@ def vit_huge_patch14_224_in21k():
     """
     cfg = ViTConfig(
         name="vit_huge_patch14_224_in21k",
-        url="",
+        url="[timm]",
         nb_classes=21843,
         patch_size=14,
         embed_dim=1280,
@@ -892,7 +947,7 @@ def deit_tiny_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_tiny_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=192,
         nb_blocks=12,
@@ -911,7 +966,7 @@ def deit_small_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_small_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=384,
         nb_blocks=12,
@@ -930,7 +985,7 @@ def deit_base_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_base_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=768,
         nb_blocks=12,
@@ -949,7 +1004,7 @@ def deit_base_patch16_384():
     """
     cfg = ViTConfig(
         name="deit_base_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=768,
@@ -970,7 +1025,7 @@ def deit_tiny_distilled_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_tiny_distilled_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=192,
         nb_blocks=12,
@@ -991,7 +1046,7 @@ def deit_small_distilled_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_small_distilled_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=384,
         nb_blocks=12,
@@ -1012,7 +1067,7 @@ def deit_base_distilled_patch16_224():
     """
     cfg = ViTConfig(
         name="deit_base_distilled_patch16_224",
-        url="",
+        url="[timm]",
         patch_size=16,
         embed_dim=768,
         nb_blocks=12,
@@ -1033,7 +1088,7 @@ def deit_base_distilled_patch16_384():
     """
     cfg = ViTConfig(
         name="deit_base_distilled_patch16_384",
-        url="",
+        url="[timm]",
         input_size=(384, 384),
         patch_size=16,
         embed_dim=768,
@@ -1056,7 +1111,7 @@ def vit_base_patch16_224_miil_in21k():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_224_miil_in21k",
-        url="",
+        url="[timm]",
         nb_classes=11221,
         input_size=(224, 224),
         patch_size=16,
@@ -1081,7 +1136,7 @@ def vit_base_patch16_224_miil():
     """
     cfg = ViTConfig(
         name="vit_base_patch16_224_miil",
-        url="",
+        url="[timm]",
         input_size=(224, 224),
         patch_size=16,
         embed_dim=768,
